"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCopySnapshotPresignedUrlPlugin = exports.copySnapshotPresignedUrlMiddlewareOptions = exports.copySnapshotPresignedUrlMiddleware = void 0;
const util_format_url_1 = require("@aws-sdk/util-format-url");
const middleware_endpoint_1 = require("@smithy/middleware-endpoint");
const protocol_http_1 = require("@smithy/protocol-http");
const signature_v4_1 = require("@smithy/signature-v4");
const smithy_client_1 = require("@smithy/smithy-client");
const version = "2016-11-15";
function copySnapshotPresignedUrlMiddleware(options) {
    return (next, context) => async (args) => {
        var _a, _b;
        const { input } = args;
        if (!input.PresignedUrl) {
            const destinationRegion = await options.region();
            const endpoint = await (0, middleware_endpoint_1.getEndpointFromInstructions)(input, {
                getEndpointParameterInstructions() {
                    return {
                        UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
                        Endpoint: { type: "builtInParams", name: "endpoint" },
                        Region: { type: "builtInParams", name: "region" },
                        UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" },
                    };
                },
            }, {
                ...options,
                region: input.SourceRegion,
            });
            const resolvedEndpoint = typeof options.endpoint === "function" ? await options.endpoint() : (0, middleware_endpoint_1.toEndpointV1)(endpoint);
            const requestToSign = new protocol_http_1.HttpRequest({
                ...resolvedEndpoint,
                protocol: "https",
                headers: {
                    host: resolvedEndpoint.hostname,
                },
                query: {
                    ...Object.entries(input).reduce((acc, [k, v]) => {
                        acc[k] = String(v !== null && v !== void 0 ? v : "");
                        return acc;
                    }, {}),
                    Action: "CopySnapshot",
                    Version: version,
                    DestinationRegion: destinationRegion,
                },
            });
            const signer = new signature_v4_1.SignatureV4({
                credentials: options.credentials,
                region: input.SourceRegion,
                service: "ec2",
                sha256: options.sha256,
                uriEscapePath: options.signingEscapePath,
            });
            const presignedRequest = await signer.presign(requestToSign, {
                expiresIn: 3600,
            });
            args = {
                ...args,
                input: {
                    ...args.input,
                    DestinationRegion: destinationRegion,
                    PresignedUrl: (0, util_format_url_1.formatUrl)(presignedRequest),
                },
            };
            if (protocol_http_1.HttpRequest.isInstance(args.request)) {
                const { request } = args;
                if (!((_a = request.body) !== null && _a !== void 0 ? _a : "").includes("DestinationRegion=")) {
                    request.body += `&DestinationRegion=${destinationRegion}`;
                }
                if (!((_b = request.body) !== null && _b !== void 0 ? _b : "").includes("PresignedUrl=")) {
                    request.body += `&PresignedUrl=${(0, smithy_client_1.extendedEncodeURIComponent)(args.input.PresignedUrl)}`;
                }
            }
        }
        return next(args);
    };
}
exports.copySnapshotPresignedUrlMiddleware = copySnapshotPresignedUrlMiddleware;
exports.copySnapshotPresignedUrlMiddlewareOptions = {
    step: "serialize",
    tags: ["CROSS_REGION_PRESIGNED_URL"],
    name: "crossRegionPresignedUrlMiddleware",
    override: true,
    relation: "after",
    toMiddleware: "endpointV2Middleware",
};
const getCopySnapshotPresignedUrlPlugin = (config) => ({
    applyToStack: (clientStack) => {
        clientStack.add(copySnapshotPresignedUrlMiddleware(config), exports.copySnapshotPresignedUrlMiddlewareOptions);
    },
});
exports.getCopySnapshotPresignedUrlPlugin = getCopySnapshotPresignedUrlPlugin;
